@@ -7,53 +7,53 @@
 #![allow(clippy::vec_init_then_push)]
 #![allow(rustdoc::bare_urls)]
 #![warn(missing_docs)]
-//! <fullname>AWS Support</fullname>
-//! <p>The <i>AWS Support API Reference</i> is intended for programmers who need detailed
-//! information about the AWS Support operations and data types. You can use the API to manage
-//! your support cases programmatically. The AWS Support API uses HTTP methods that return
+//! <fullname>Amazon Web Services Support</fullname>
+//! <p>The <i>Amazon Web Services Support API Reference</i> is intended for programmers who need detailed
+//! information about the Amazon Web Services Support operations and data types. You can use the API to manage
+//! your support cases programmatically. The Amazon Web Services Support API uses HTTP methods that return
 //! results in JSON format.</p>
 //! <note>
 //! <ul>
 //! <li>
-//! <p>You must have a Business or Enterprise Support plan to use the AWS Support
+//! <p>You must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the Amazon Web Services Support
 //! API. </p>
 //! </li>
 //! <li>
-//! <p>If you call the AWS Support API from an account that does not have a
-//! Business or Enterprise Support plan, the
+//! <p>If you call the Amazon Web Services Support API from an account that does not have a
+//! Business, Enterprise On-Ramp, or Enterprise Support plan, the
 //! <code>SubscriptionRequiredException</code> error message appears. For
-//! information about changing your support plan, see <a href="http://aws.amazon.com/premiumsupport/">AWS Support</a>.</p>
+//! information about changing your support plan, see <a href="http://aws.amazon.com/premiumsupport/">Amazon Web Services Support</a>.</p>
 //! </li>
 //! </ul>
 //! </note>
-//! <p>The AWS Support service also exposes a set of <a href="http://aws.amazon.com/premiumsupport/trustedadvisor/">AWS Trusted Advisor</a> features. You can
+//! <p>The Amazon Web Services Support service also exposes a set of <a href="http://aws.amazon.com/premiumsupport/trustedadvisor/">Trusted Advisor</a> features. You can
 //! retrieve a list of checks and their descriptions, get check results, specify checks to
 //! refresh, and get the refresh status of checks.</p>
-//! <p>The following list describes the AWS Support case management operations:</p>
+//! <p>The following list describes the Amazon Web Services Support case management operations:</p>
 //! <ul>
 //! <li>
 //! <p> Service names, issue categories, and available severity levels  - The
-//! <a>DescribeServices</a> and <a>DescribeSeverityLevels</a> operations return AWS service names,
+//! <a>DescribeServices</a> and <a>DescribeSeverityLevels</a> operations return Amazon Web Services service names,
 //! service codes, service categories, and problem severity levels. You use these
 //! values when you call the <a>CreateCase</a> operation.</p>
 //! </li>
 //! <li>
 //! <p> Case creation, case details, and case resolution - The <a>CreateCase</a>, <a>DescribeCases</a>, <a>DescribeAttachment</a>, and <a>ResolveCase</a> operations
-//! create AWS Support cases, retrieve information about cases, and resolve cases.</p>
+//! create Amazon Web Services Support cases, retrieve information about cases, and resolve cases.</p>
 //! </li>
 //! <li>
 //! <p> Case communication - The <a>DescribeCommunications</a>,
 //! <a>AddCommunicationToCase</a>, and <a>AddAttachmentsToSet</a> operations retrieve and add communications
-//! and attachments to AWS Support cases.</p>
+//! and attachments to Amazon Web Services Support cases.</p>
 //! </li>
 //! </ul>
-//! <p>The following list describes the operations available from the AWS Support service for
+//! <p>The following list describes the operations available from the Amazon Web Services Support service for
 //! Trusted Advisor:</p>
 //! <ul>
 //! <li>
 //! <p>
 //! <a>DescribeTrustedAdvisorChecks</a> returns the list of checks that
-//! run against your AWS resources.</p>
+//! run against your Amazon Web Services resources.</p>
 //! </li>
 //! <li>
 //! <p>Using the <code>checkId</code> for a specific check returned by <a>DescribeTrustedAdvisorChecks</a>, you can call <a>DescribeTrustedAdvisorCheckResult</a> to obtain the results for the
@@ -75,10 +75,10 @@
 //! status of one or more checks.</p>
 //! </li>
 //! </ul>
-//! <p>For authentication of requests, AWS Support uses <a href="https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html">Signature Version 4 Signing
+//! <p>For authentication of requests, Amazon Web Services Support uses <a href="https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html">Signature Version 4 Signing
 //! Process</a>.</p>
 //! <p>See <a href="https://docs.aws.amazon.com/awssupport/latest/user/Welcome.html">About the
-//! AWS Support API</a> in the <i>AWS Support User Guide</i> for
+//! Amazon Web Services Support API</a> in the <i>Amazon Web Services Support User Guide</i> for
 //! information about how to use this service to create and manage your support cases, and
 //! how to call Trusted Advisor for results of checks on your resources.</p>
 //!
@@ -112,6 +112,8 @@ pub mod input;
 mod json_deser;
 mod json_errors;
 mod json_ser;
+/// Generated accessors for nested fields
+mod lens;
 pub mod middleware;
 /// Data structures used by operation inputs/outputs.
 pub mod model;
@@ -122,6 +124,8 @@ mod operation_deser;
 mod operation_ser;
 /// Output structures for operations.
 pub mod output;
+/// Paginators for the service
+pub mod paginator;
 /// Crate version number.
 pub static PKG_VERSION: &str = env!("CARGO_PKG_VERSION");
 pub use aws_smithy_http::byte_stream::ByteStream;
